@@ -6,7 +6,7 @@
 ;; Homepage: https://github.com/ahyatt/triples
 ;; Package-Requires: ((seq "2.0") (emacs "28.1"))
 ;; Keywords: triples, kg, data, sqlite
-;; Version: 0.2.5
+;; Version: 0.2.6
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
 ;; published by the Free Software Foundation; either version 2 of the
@@ -564,8 +564,9 @@ data you own with `triples-remove-type'."
   (triples-db-select db nil cpred))
 
 (defun triples-subjects-with-predicate-object (db cpred obj)
-  "Return all subjects in DB with CPRED equal to OBJ."
-  (mapcar #'car (triples-db-select db nil cpred obj)))
+  "Return all subjects in DB with CPRED equal to OBJ.
+Subjects will not be returned more than once."
+  (seq-uniq (mapcar #'car (triples-db-select db nil cpred obj))))
 
 (defun triples-subjects-of-type (db type)
   "Return a list of all subjects with a particular TYPE in DB."
